# Code generated by stigmer-codegen. DO NOT EDIT.

from __future__ import annotations

import grpc

from ._agent import AgentClient
from ._agentexecution import AgentExecutionClient
from ._agentinstance import AgentInstanceClient
from ._apikey import ApiKeyClient
from ._environment import EnvironmentClient
from ._executioncontext import ExecutionContextClient
from ._iampolicy import IamPolicyClient
from ._identityaccount import IdentityAccountClient
from ._identityprovider import IdentityProviderClient
from ._mcpserver import McpServerClient
from ._organization import OrganizationClient
from ._project import ProjectClient
from ._session import SessionClient
from ._skill import SkillClient
from ._workflow import WorkflowClient
from ._workflowexecution import WorkflowExecutionClient
from ._workflowinstance import WorkflowInstanceClient


class GeneratedClient:
    """Aggregate client composing all resource-specific sub-clients."""

    def __init__(self, channel: grpc.Channel) -> None:
        self.agents = AgentClient(channel)
        self.agent_executions = AgentExecutionClient(channel)
        self.agent_instances = AgentInstanceClient(channel)
        self.api_keys = ApiKeyClient(channel)
        self.environments = EnvironmentClient(channel)
        self.execution_contexts = ExecutionContextClient(channel)
        self.iam_policies = IamPolicyClient(channel)
        self.identity_accounts = IdentityAccountClient(channel)
        self.identity_providers = IdentityProviderClient(channel)
        self.mcp_servers = McpServerClient(channel)
        self.organizations = OrganizationClient(channel)
        self.projects = ProjectClient(channel)
        self.sessions = SessionClient(channel)
        self.skills = SkillClient(channel)
        self.workflows = WorkflowClient(channel)
        self.workflow_executions = WorkflowExecutionClient(channel)
        self.workflow_instances = WorkflowInstanceClient(channel)

